@@ -1,15 +1,17 @@
 class Undefined:
     def __str__(self):
-        return 'undefined'
+        return "undefined"
 
     def __bool__(self):
         return False
 
     def __eq__(self, other):
         return isinstance(other, self.__class__)
-        
+
+
 undefined = Undefined()
 
+
 class ActivityBar:
     def __init__(self, id, title, icon):
         self.id = id
@@ -17,6 +19,13 @@ class ActivityBar:
         self.icon = icon
 
 
+class StaticWebview:
+    def __init__(self, id, html, title=None):
+        self.id = id
+        self.html = html
+        self.title = title
+
+
 class InputBoxOptions:
     def __init__(
         self,
@@ -34,6 +43,7 @@ class InputBoxOptions:
         self.placeHolder = place_holder
         self.value = value
 
+
 class QuickPickOptions:
     def __init__(
         self,
@@ -49,4 +59,4 @@ class QuickPickOptions:
         self.ignoreFocusOut = ignore_focus_out
         self.matchOnDescription = match_on_description
         self.placeHolder = place_holder
-        self.matchOnDetail = match_on_detail
\ No newline at end of file
+        self.matchOnDetail = match_on_detail
